use ema;

/* ver. 1.06 */
SET @dbname = "ema";
SET @tablename = "nastavenia";
SET @columnname = "language";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS
    WHERE
      (table_name = @tablename)
      AND (table_schema = @dbname)
      AND (column_name = @columnname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD ", @columnname, " TINYINT NOT NULL DEFAULT '0';")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;


/* ver. 1.07, 1.08 */
delete from prava where not exists(select id from uzivatelia where uzivatelia.kod=prava.kod_uziv) or not exists(select id from lokacie where lokacie.kod=prava.kod_lok);

SET @constraintschema = "ema";
SET @tablename = "prava";
SET @constraintname = "prava_fk_koduziv";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS
    WHERE (CONSTRAINT_SCHEMA = @constraintschema) AND (CONSTRAINT_NAME = @constraintname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD CONSTRAINT ", @constraintname, " FOREIGN KEY (kod_uziv) REFERENCES uzivatelia(kod) ON DELETE CASCADE ON UPDATE CASCADE;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;

SET @constraintschema = "ema";
SET @tablename = "prava";
SET @constraintname = "prava_fk_kodlok";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS
    WHERE (CONSTRAINT_SCHEMA = @constraintschema) AND (CONSTRAINT_NAME = @constraintname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD CONSTRAINT ", @constraintname, " FOREIGN KEY (kod_lok) REFERENCES lokacie(kod) ON DELETE CASCADE ON UPDATE CASCADE;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;

/*ALTER TABLE `majetok` ADD `datum_vyrad` DATE NULL DEFAULT NULL AFTER `vymazal`;*/
SET @dbname = "ema";
SET @tablename = "majetok";
SET @columnname = "datum_vyrad";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS
    WHERE
      (table_name = @tablename)
      AND (table_schema = @dbname)
      AND (column_name = @columnname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD ", @columnname, " DATE NULL DEFAULT NULL AFTER `vymazal`;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;


/*ALTER TABLE `nastavenia`  ADD `sablona_user` VARCHAR(40) NOT NULL  AFTER `sablona_maj`;*/
SET @dbname = "ema";
SET @tablename = "nastavenia";
SET @columnname = "sablona_user";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS
    WHERE
      (table_name = @tablename)
      AND (table_schema = @dbname)
      AND (column_name = @columnname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD ", @columnname, " VARCHAR(40) NOT NULL AFTER `sablona_maj`;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;

UPDATE nastavenia SET sablona_user = '../DPL_uzivatel.txt' WHERE id=1 and coalesce(sablona_user, '')='';

/*ALTER TABLE `nastavenia`  ADD `ftp_printer` TINYINT(4) NOT NULL  AFTER `sablona_maj`;*/
SET @dbname = "ema";
SET @tablename = "nastavenia";
SET @columnname = "ftp_printer";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS
    WHERE
      (table_name = @tablename)
      AND (table_schema = @dbname)
      AND (column_name = @columnname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD ", @columnname, " tinyint(4) NOT NULL DEFAULT 0 AFTER `backup_dir`;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;

/* ver. 2.04 */
SET @dbname = "ema";
SET @tablename = "nastavenia";
SET @columnname = "doc_path";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS
    WHERE
      (table_name = @tablename)
      AND (table_schema = @dbname)
      AND (column_name = @columnname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD ", @columnname, " VARCHAR(256) NOT NULL AFTER `language`;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;

CREATE TABLE IF NOT EXISTS files (
	`id` int(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
	`web_path` varchar(130) COLLATE utf8_slovak_ci NOT NULL,
	`system_path` varchar(130) COLLATE utf8_slovak_ci NOT NULL,
	`typ` tinyint(4) NOT NULL DEFAULT 0
	) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_slovak_ci;
	
CREATE TABLE IF NOT EXISTS majetok_file (
	`majetok_id` int(11) NOT NULL,
	`file_id` int(11) NOT NULL 
	) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_slovak_ci;
	
SET @dbname = "ema";
SET @tablename = "majetok_file";
SET @indexname = "majetok_fileid";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.STATISTICS
    WHERE
      (table_name = @tablename)
      AND (table_schema = @dbname)
      AND (index_name like @indexname)
  ) > 0,
  "SELECT 1",
  CONCAT("ALTER TABLE ", @tablename, " ADD KEY ", @indexname, " (`majetok_id`,`file_id`) USING BTREE;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;

DELIMITER $$
DROP TRIGGER IF EXISTS `majetok_ad`$$
CREATE TRIGGER `majetok_ad` AFTER DELETE ON `majetok` FOR EACH ROW BEGIN
  delete from majetok_file where majetok_id=OLD.id;
  delete from files where not exists(select id from majetok_file where majetok_file.file_id=files.id);
END$$
DELIMITER ;

ALTER TABLE `majetok` CHANGE `novy` `novy` TINYINT(1) NOT NULL DEFAULT 0;

/* ver. 3.00 */
SET @dbname = "ema";
SET @tablename = "lokacie";
SET @columnname = "nadrad_kod";
SET @preparedStatement = (SELECT IF(
  (
    SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS
    WHERE
      (table_name = @tablename)
      AND (table_schema = @dbname)
      AND (column_name = @columnname)
  ) > 0,
  "SELECT 1",
  CONCAT("alter table ", @tablename, " ADD ", @columnname, " varchar(20) not null after `nazov`;")
));
PREPARE alterIfNotExists FROM @preparedStatement;
EXECUTE alterIfNotExists;
DEALLOCATE PREPARE alterIfNotExists;

update nastavenia set verzia = '300';
